import * as React from 'react';
import { observer } from 'mobx-react';
import { Spinner } from '@patternfly/react-core';
import ElementContext from '../utils/ElementContext';
import ContextMenu from '../components/contextmenu/ContextMenu';
export const withContextMenu = (actions, container, className, atPoint = true, waitElement = React.createElement(Spinner, { className: "pf-v6-u-mx-md", size: "md" })) => (WrappedComponent) => {
    const Component = (props) => {
        const element = React.useContext(ElementContext);
        const [reference, setReference] = React.useState(null);
        const [elementActions, setElementActions] = React.useState(null);
        const onContextMenu = React.useCallback((e) => {
            e.preventDefault();
            e.stopPropagation();
            setReference(atPoint
                ? {
                    x: e.pageX,
                    y: e.pageY
                }
                : e.currentTarget);
        }, []);
        React.useEffect(() => {
            if (reference) {
                const actionsElements = actions(element);
                Promise.resolve(actionsElements).then((resultActions) => {
                    setElementActions(resultActions);
                });
            }
            else {
                setElementActions(null);
            }
        }, [element, reference]);
        return (React.createElement(React.Fragment, null,
            React.createElement(WrappedComponent, Object.assign({}, props, { onContextMenu: onContextMenu, contextMenuOpen: !!reference })),
            reference ? (React.createElement(ContextMenu, { reference: reference, container: container, className: className, open: true, onRequestClose: () => setReference(null) }, elementActions || waitElement)) : null));
    };
    Component.displayName = `withContextMenu(${WrappedComponent.displayName || WrappedComponent.name})`;
    return observer(Component);
};
//# sourceMappingURL=withContextMenu.js.map