import * as React from 'react';
import { observer } from 'mobx-react';
import { isGraph } from '../types';
import styles from '../css/topology-components';
import useCombineRefs from '../utils/useCombineRefs';
import LayersProvider from './layers/LayersProvider';
import ElementWrapper from './ElementWrapper';
// This inner Component will prevent the re-rendering of all children when the transform changes
const ElementChildren = observer(({ element }) => (React.createElement(React.Fragment, null,
    element.getEdges().map((e) => (React.createElement(ElementWrapper, { key: e.getId(), element: e }))),
    element.getNodes().map((e) => (React.createElement(ElementWrapper, { key: e.getId(), element: e }))))));
// This inner Component will prevent re-rendering layers when the transform changes
const Inner = React.memo(observer(({ element }) => (React.createElement(LayersProvider, { layers: element.getLayers() },
    React.createElement(ElementChildren, { element: element })))));
const GraphComponent = ({ element, panZoomRef, areaSelectionRef, dndDropRef, onSelect, onContextMenu, isAreaSelectDragging, areaSelectDragStart, areaSelectDragEnd }) => {
    const zoomRefs = useCombineRefs(panZoomRef, areaSelectionRef);
    if (!isGraph(element)) {
        return null;
    }
    const graphElement = element;
    const { x, y, width, height } = graphElement.getBounds();
    return (React.createElement(React.Fragment, null,
        React.createElement("rect", { ref: dndDropRef, x: 0, y: 0, width: width, height: height, fillOpacity: 0, onClick: onSelect, onContextMenu: onContextMenu }),
        React.createElement("g", { "data-surface": "true", ref: zoomRefs, transform: `translate(${x}, ${y}) scale(${graphElement.getScale()})` },
            React.createElement(Inner, { element: graphElement })),
        isAreaSelectDragging && areaSelectDragStart && areaSelectDragEnd ? (React.createElement("rect", { className: styles.topologyAreaSelectRect, x: Math.min(areaSelectDragStart.x, areaSelectDragEnd.x), y: Math.min(areaSelectDragStart.y, areaSelectDragEnd.y), width: Math.abs(areaSelectDragEnd.x - areaSelectDragStart.x), height: Math.abs(areaSelectDragEnd.y - areaSelectDragStart.y) })) : null));
};
export default observer(GraphComponent);
//# sourceMappingURL=GraphComponent.js.map