import * as React from 'react';
import { EdgeStyle, EdgeTerminalType, GraphElement, NodeStatus } from '../../types';
import { ConnectDragSource, ConnectDropTarget, OnSelect } from '../../behavior';
interface DefaultEdgeProps {
    /** Additional content added to the edge */
    children?: React.ReactNode;
    /** Additional classes added to the edge */
    className?: string;
    /** The graph edge element to represent */
    element: GraphElement;
    /** Flag indicating if the user is dragging the edge */
    dragging?: boolean;
    /** The style of the edge. Defaults to the style set on the Edge's model */
    edgeStyle?: EdgeStyle;
    /** The duration in seconds for the edge animation. Defaults to the animationSpeed set on the Edge's model */
    animationDuration?: number;
    /** The terminal type to use for the edge start */
    startTerminalType?: EdgeTerminalType;
    /** Additional classes added to the start terminal */
    startTerminalClass?: string;
    /** The status to indicate on the start terminal */
    startTerminalStatus?: NodeStatus;
    /** The size of the start terminal */
    startTerminalSize?: number;
    /** The terminal type to use for the edge end */
    endTerminalType?: EdgeTerminalType;
    /** Additional classes added to the end terminal */
    endTerminalClass?: string;
    /** The status to indicate on the end terminal */
    endTerminalStatus?: NodeStatus;
    /** The size of the end terminal */
    endTerminalSize?: number;
    /** Tag to show for the terminal */
    tag?: string;
    /** Additional classes added to the tag */
    tagClass?: string;
    /** The status to indicate on the tag */
    tagStatus?: NodeStatus;
    /** Function to call for showing a remove indicator on the edge. Part of WithRemoveConnectorProps  */
    onShowRemoveConnector?: () => void;
    /** Function to call for removing the remove indicator on the edge. Part of WithRemoveConnectorProps  */
    onHideRemoveConnector?: () => void;
    /** Ref to use to start the drag of the start of the edge. Part of WithSourceDragProps */
    sourceDragRef?: ConnectDragSource;
    /** Ref to use to start the drag of the end of the edge. Part of WithTargetDragProps */
    targetDragRef?: ConnectDragSource;
    /** A ref to add to the node for dropping. Part of WithDndDropProps */
    dndDropRef?: ConnectDropTarget;
    /** Flag if the current drag operation can be dropped on the edge */
    canDrop?: boolean;
    /** Flag if the node is the current drop target */
    dropTarget?: boolean;
    /** Flag indicating if the element is selected. Part of WithSelectionProps */
    selected?: boolean;
    /** Function to call when the element should become selected (or deselected). Part of WithSelectionProps */
    onSelect?: OnSelect;
    /** Function to call to show a context menu for the edge  */
    onContextMenu?: (e: React.MouseEvent) => void;
    /** Flag indicating that the context menu for the edge is currently open  */
    contextMenuOpen?: boolean;
}
declare const DefaultEdge: React.FunctionComponent<DefaultEdgeProps>;
export default DefaultEdge;
//# sourceMappingURL=DefaultEdge.d.ts.map