"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withContextMenu = void 0;
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const mobx_react_1 = require("mobx-react");
const react_core_1 = require("@patternfly/react-core");
const ElementContext_1 = tslib_1.__importDefault(require("../utils/ElementContext"));
const ContextMenu_1 = tslib_1.__importDefault(require("../components/contextmenu/ContextMenu"));
const withContextMenu = (actions, container, className, atPoint = true, waitElement = React.createElement(react_core_1.Spinner, { className: "pf-v6-u-mx-md", size: "md" })) => (WrappedComponent) => {
    const Component = (props) => {
        const element = React.useContext(ElementContext_1.default);
        const [reference, setReference] = React.useState(null);
        const [elementActions, setElementActions] = React.useState(null);
        const onContextMenu = React.useCallback((e) => {
            e.preventDefault();
            e.stopPropagation();
            setReference(atPoint
                ? {
                    x: e.pageX,
                    y: e.pageY
                }
                : e.currentTarget);
        }, []);
        React.useEffect(() => {
            if (reference) {
                const actionsElements = actions(element);
                Promise.resolve(actionsElements).then((resultActions) => {
                    setElementActions(resultActions);
                });
            }
            else {
                setElementActions(null);
            }
        }, [element, reference]);
        return (React.createElement(React.Fragment, null,
            React.createElement(WrappedComponent, Object.assign({}, props, { onContextMenu: onContextMenu, contextMenuOpen: !!reference })),
            reference ? (React.createElement(ContextMenu_1.default, { reference: reference, container: container, className: className, open: true, onRequestClose: () => setReference(null) }, elementActions || waitElement)) : null));
    };
    Component.displayName = `withContextMenu(${WrappedComponent.displayName || WrappedComponent.name})`;
    return (0, mobx_react_1.observer)(Component);
};
exports.withContextMenu = withContextMenu;
//# sourceMappingURL=withContextMenu.js.map