"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const mobx_react_1 = require("mobx-react");
const types_1 = require("../types");
const topology_components_1 = tslib_1.__importDefault(require("../css/topology-components"));
const useCombineRefs_1 = tslib_1.__importDefault(require("../utils/useCombineRefs"));
const LayersProvider_1 = tslib_1.__importDefault(require("./layers/LayersProvider"));
const ElementWrapper_1 = tslib_1.__importDefault(require("./ElementWrapper"));
// This inner Component will prevent the re-rendering of all children when the transform changes
const ElementChildren = (0, mobx_react_1.observer)(({ element }) => (React.createElement(React.Fragment, null,
    element.getEdges().map((e) => (React.createElement(ElementWrapper_1.default, { key: e.getId(), element: e }))),
    element.getNodes().map((e) => (React.createElement(ElementWrapper_1.default, { key: e.getId(), element: e }))))));
// This inner Component will prevent re-rendering layers when the transform changes
const Inner = React.memo((0, mobx_react_1.observer)(({ element }) => (React.createElement(LayersProvider_1.default, { layers: element.getLayers() },
    React.createElement(ElementChildren, { element: element })))));
const GraphComponent = ({ element, panZoomRef, areaSelectionRef, dndDropRef, onSelect, onContextMenu, isAreaSelectDragging, areaSelectDragStart, areaSelectDragEnd }) => {
    const zoomRefs = (0, useCombineRefs_1.default)(panZoomRef, areaSelectionRef);
    if (!(0, types_1.isGraph)(element)) {
        return null;
    }
    const graphElement = element;
    const { x, y, width, height } = graphElement.getBounds();
    return (React.createElement(React.Fragment, null,
        React.createElement("rect", { ref: dndDropRef, x: 0, y: 0, width: width, height: height, fillOpacity: 0, onClick: onSelect, onContextMenu: onContextMenu }),
        React.createElement("g", { "data-surface": "true", ref: zoomRefs, transform: `translate(${x}, ${y}) scale(${graphElement.getScale()})` },
            React.createElement(Inner, { element: graphElement })),
        isAreaSelectDragging && areaSelectDragStart && areaSelectDragEnd ? (React.createElement("rect", { className: topology_components_1.default.topologyAreaSelectRect, x: Math.min(areaSelectDragStart.x, areaSelectDragEnd.x), y: Math.min(areaSelectDragStart.y, areaSelectDragEnd.y), width: Math.abs(areaSelectDragEnd.x - areaSelectDragStart.x), height: Math.abs(areaSelectDragEnd.y - areaSelectDragStart.y) })) : null));
};
exports.default = (0, mobx_react_1.observer)(GraphComponent);
//# sourceMappingURL=GraphComponent.js.map