"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const react_styles_1 = require("@patternfly/react-styles");
const topology_components_1 = tslib_1.__importDefault(require("../../../css/topology-components"));
const truncate_middle_1 = require("../../../utils/truncate-middle");
const utils_1 = require("../../../utils");
const NodeShadows_1 = tslib_1.__importStar(require("../NodeShadows"));
const LabelBadge_1 = tslib_1.__importDefault(require("./LabelBadge"));
const LabelContextMenu_1 = tslib_1.__importDefault(require("./LabelContextMenu"));
const LabelIcon_1 = tslib_1.__importDefault(require("./LabelIcon"));
const LabelActionIcon_1 = tslib_1.__importDefault(require("./LabelActionIcon"));
const types_1 = require("../../../types");
/**
 * Renders a `<text>` component with a `<rect>` box behind.
 */
const NodeLabel = (_a) => {
    var _b;
    var { children, className, paddingX = 0, paddingY = 0, cornerRadius = 4, x = 0, y = 0, position = types_1.LabelPosition.bottom, centerLabelOnEdge, secondaryLabel, status, badge, badgeColor, badgeTextColor, badgeBorderColor, badgeClassName, badgeLocation = types_1.BadgeLocation.inner, labelIconClass, labelIcon, labelIconPadding = 4, truncateLength, dragRef, hover, dragging, edgeDragging, dropTarget, onContextMenu, contextMenuOpen, hideContextMenuKebab, actionIcon, actionIconClassName, onActionIconClick, boxRef } = _a, other = tslib_1.__rest(_a, ["children", "className", "paddingX", "paddingY", "cornerRadius", "x", "y", "position", "centerLabelOnEdge", "secondaryLabel", "status", "badge", "badgeColor", "badgeTextColor", "badgeBorderColor", "badgeClassName", "badgeLocation", "labelIconClass", "labelIcon", "labelIconPadding", "truncateLength", "dragRef", "hover", "dragging", "edgeDragging", "dropTarget", "onContextMenu", "contextMenuOpen", "hideContextMenuKebab", "actionIcon", "actionIconClassName", "onActionIconClick", "boxRef"]);
    const [labelHover, labelHoverRef] = (0, utils_1.useHover)();
    const refs = (0, utils_1.useCombineRefs)(dragRef, typeof truncateLength === 'number' ? labelHoverRef : undefined);
    const [textSize, textRef] = (0, utils_1.useSize)([children, truncateLength, className, labelHover, contextMenuOpen]);
    const [secondaryTextSize, secondaryTextRef] = (0, utils_1.useSize)([secondaryLabel, truncateLength, className, labelHover]);
    const [badgeSize, badgeRef] = (0, utils_1.useSize)([badge]);
    const [actionSize, actionRef] = (0, utils_1.useSize)([actionIcon, paddingX]);
    const [contextSize, contextRef] = (0, utils_1.useSize)([onContextMenu, paddingX]);
    const { width, height, backgroundHeight, startX, startY, badgeStartX, badgeStartY, actionStartX, contextStartX, iconSpace, badgeSpace } = React.useMemo(() => {
        var _a;
        if (!textSize) {
            return {
                width: 0,
                height: 0,
                backgroundHeight: 0,
                startX: 0,
                startY: 0,
                badgeStartX: 0,
                badgeStartY: 0,
                actionStartX: 0,
                contextStartX: 0,
                iconSpace: 0,
                badgeSpace: 0
            };
        }
        const badgeSpace = badge && badgeSize && badgeLocation === types_1.BadgeLocation.inner ? badgeSize.width + paddingX : 0;
        const height = Math.max(textSize.height, (_a = badgeSize === null || badgeSize === void 0 ? void 0 : badgeSize.height) !== null && _a !== void 0 ? _a : 0) + paddingY * 2;
        const iconSpace = labelIconClass || labelIcon ? (height + paddingY * 0.5) / 2 : 0;
        const actionSpace = actionIcon && actionSize ? actionSize.width : 0;
        const contextSpace = !hideContextMenuKebab && onContextMenu && contextSize ? contextSize.width : 0;
        const primaryWidth = iconSpace + badgeSpace + paddingX + textSize.width + actionSpace + contextSpace + paddingX;
        const secondaryWidth = secondaryLabel && secondaryTextSize ? secondaryTextSize.width + 2 * paddingX : 0;
        const width = Math.max(primaryWidth, secondaryWidth);
        const backgroundHeight = height + (secondaryLabel && secondaryTextSize ? secondaryTextSize.height + paddingY * 2 : 0);
        let startX;
        let startY;
        if (position === types_1.LabelPosition.top) {
            startX = x - width / 2;
            startY = -y - height - (centerLabelOnEdge ? -backgroundHeight / 2 : paddingY);
        }
        else if (position === types_1.LabelPosition.right) {
            startX = x + iconSpace - (centerLabelOnEdge ? width / 2 : 0);
            startY = y - height / 2;
        }
        else if (position === types_1.LabelPosition.left) {
            startX = centerLabelOnEdge ? x - width / 2 : -width - paddingX;
            startY = y - height / 2;
        }
        else {
            startX = x - width / 2 + iconSpace / 2;
            startY = y - (centerLabelOnEdge ? backgroundHeight / 2 : 0);
        }
        const actionStartX = iconSpace + badgeSpace + paddingX + textSize.width + paddingX;
        const contextStartX = actionStartX + actionSpace;
        let badgeStartX = 0;
        let badgeStartY = 0;
        if (badgeSize) {
            if (badgeLocation === types_1.BadgeLocation.below) {
                badgeStartX = (width - badgeSize.width) / 2;
                badgeStartY = height + paddingY;
            }
            else {
                badgeStartX = iconSpace + paddingX;
                badgeStartY = (height - badgeSize.height) / 2;
            }
        }
        return {
            width,
            height,
            backgroundHeight,
            startX,
            startY,
            actionStartX,
            contextStartX,
            badgeStartX,
            badgeStartY,
            iconSpace,
            badgeSpace: badgeSize && badgeLocation === types_1.BadgeLocation.inner ? badgeSpace : 0
        };
    }, [
        textSize,
        badge,
        badgeSize,
        badgeLocation,
        paddingX,
        paddingY,
        labelIconClass,
        labelIcon,
        actionIcon,
        actionSize,
        hideContextMenuKebab,
        onContextMenu,
        contextSize,
        secondaryLabel,
        secondaryTextSize,
        centerLabelOnEdge,
        position,
        x,
        y
    ]);
    let filterId;
    if (status === 'danger') {
        filterId = NodeShadows_1.NODE_SHADOW_FILTER_ID_DANGER;
    }
    else if (hover || dragging || edgeDragging || dropTarget) {
        filterId = NodeShadows_1.NODE_SHADOW_FILTER_ID_HOVER;
    }
    return (React.createElement("g", { className: className, ref: refs, transform: `translate(${startX}, ${startY})` },
        React.createElement(NodeShadows_1.default, null),
        textSize && (React.createElement("rect", { ref: boxRef, className: (0, react_styles_1.css)(topology_components_1.default.topologyNodeLabelBackground), key: `rect-${filterId}-${width}`, filter: filterId && (0, utils_1.createSvgIdUrl)(filterId), x: 0, y: 0, width: width, height: backgroundHeight, rx: cornerRadius, ry: cornerRadius })),
        textSize && badge && (React.createElement(LabelBadge_1.default, { ref: badgeRef, x: badgeStartX, y: badgeStartY, badge: badge, badgeClassName: badgeClassName, badgeColor: badgeColor, badgeTextColor: badgeTextColor, badgeBorderColor: badgeBorderColor })),
        textSize && secondaryLabel && (React.createElement(React.Fragment, null,
            React.createElement("line", { className: (0, react_styles_1.css)(topology_components_1.default.topologyNodeSeparator), x1: 0, y1: height, x2: width, y2: height, shapeRendering: "crispEdges" }),
            React.createElement("text", { className: "pf-m-secondary", ref: secondaryTextRef, x: width / 2, y: height + paddingY + ((_b = secondaryTextSize === null || secondaryTextSize === void 0 ? void 0 : secondaryTextSize.height) !== null && _b !== void 0 ? _b : 0) / 2, dy: "0.35em", textAnchor: "middle" }, truncateLength > 0 && !labelHover
                ? (0, truncate_middle_1.truncateMiddle)(secondaryLabel, { length: truncateLength })
                : secondaryLabel))),
        textSize && (labelIconClass || labelIcon) && (React.createElement(LabelIcon_1.default, { x: iconSpace, y: paddingY * -0.25, width: iconSpace * 2, height: iconSpace * 2, iconClass: labelIconClass, icon: labelIcon, padding: labelIconPadding })),
        React.createElement("text", Object.assign({}, other, { ref: textRef, x: iconSpace + badgeSpace + paddingX, y: height / 2, dy: "0.35em" }), truncateLength > 0 && !labelHover && !contextMenuOpen
            ? (0, truncate_middle_1.truncateMiddle)(children, { length: truncateLength })
            : children),
        textSize && actionIcon && (React.createElement(React.Fragment, null,
            React.createElement("line", { className: (0, react_styles_1.css)(topology_components_1.default.topologyNodeSeparator), x1: actionStartX, y1: 0, x2: actionStartX, y2: height, shapeRendering: "crispEdges" }),
            React.createElement(LabelActionIcon_1.default, { ref: actionRef, x: actionStartX, y: 0, height: height, paddingX: paddingX, paddingY: paddingY, icon: actionIcon, className: actionIconClassName, onClick: onActionIconClick }))),
        textSize && onContextMenu && !hideContextMenuKebab && (React.createElement(React.Fragment, null,
            React.createElement("line", { className: (0, react_styles_1.css)(topology_components_1.default.topologyNodeSeparator), x1: contextStartX, y1: 0, x2: contextStartX, y2: height, shapeRendering: "crispEdges" }),
            React.createElement(LabelContextMenu_1.default, { ref: contextRef, x: contextStartX, y: 0, height: height, paddingX: paddingX, paddingY: paddingY, onContextMenu: onContextMenu, contextMenuOpen: contextMenuOpen })))));
};
exports.default = NodeLabel;
//# sourceMappingURL=NodeLabel.js.map